summaryrefslogtreecommitdiff
path: root/packet_states.h
diff options
context:
space:
mode:
Diffstat (limited to 'packet_states.h')
-rw-r--r--packet_states.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/packet_states.h b/packet_states.h
index 72a57fa6..99845b51 100644
--- a/packet_states.h
+++ b/packet_states.h
@@ -126,12 +126,12 @@
#endif
#ifdef ONCORE_ENABLE
- ONCORE_AT2, /* second @ */
- ONCORE_ID1, /* first character of command type */
- ONCORE_ID2, /* second character of command type */
- ONCORE_PAYLOAD,
- ONCORE_CR, /* closing CR */
- ONCORE_RECOGNIZED, /* closing LF */
+ ONCORE_AT2, /* second @ */
+ ONCORE_ID1, /* first character of command type */
+ ONCORE_PAYLOAD, /* payload eating */
+ ONCORE_CHECKSUM, /* checksum byte */
+ ONCORE_CR, /* closing CR */
+ ONCORE_RECOGNIZED, /* closing LF */
#endif